@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -26,6 +26,29 @@ class LowcodeClient(AbstractClient):
     _service = 'lowcode'
 
 
+    def CheckDeployApp(self, request):
+        """检查应用发布状态
+
+        :param request: Request instance for CheckDeployApp.
+        :type request: :class:`tencentcloud.lowcode.v20210108.models.CheckDeployAppRequest`
+        :rtype: :class:`tencentcloud.lowcode.v20210108.models.CheckDeployAppResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CheckDeployApp", params, headers=headers)
+            response = json.loads(body)
+            model = models.CheckDeployAppResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateKnowledgeSet(self, request):
         """创建知识库
 
@@ -49,6 +72,29 @@ class LowcodeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteAppBindWxApp(self, request):
+        """删除应用绑定小程序
+
+        :param request: Request instance for DeleteAppBindWxApp.
+        :type request: :class:`tencentcloud.lowcode.v20210108.models.DeleteAppBindWxAppRequest`
+        :rtype: :class:`tencentcloud.lowcode.v20210108.models.DeleteAppBindWxAppResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteAppBindWxApp", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteAppBindWxAppResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteKnowledgeDocumentSet(self, request):
         """删除知识库下文档
 
@@ -95,6 +141,29 @@ class LowcodeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeployApp(self, request):
+        """发布应用
+
+        :param request: Request instance for DeployApp.
+        :type request: :class:`tencentcloud.lowcode.v20210108.models.DeployAppRequest`
+        :rtype: :class:`tencentcloud.lowcode.v20210108.models.DeployAppResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeployApp", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeployAppResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeDataSourceList(self, request):
         """获取数据源详情列表
 
@@ -187,6 +256,29 @@ class LowcodeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def PutWxAppIdToWeApp(self, request):
+        """接口提供应用绑定微信ID功能。
+
+        :param request: Request instance for PutWxAppIdToWeApp.
+        :type request: :class:`tencentcloud.lowcode.v20210108.models.PutWxAppIdToWeAppRequest`
+        :rtype: :class:`tencentcloud.lowcode.v20210108.models.PutWxAppIdToWeAppResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("PutWxAppIdToWeApp", params, headers=headers)
+            response = json.loads(body)
+            model = models.PutWxAppIdToWeAppResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def SearchDocList(self, request):
         """知识库文档搜索接口
 
