@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,6 +23,9 @@ FAILEDOPERATION = 'FailedOperation'
 # 调用交易服务发生异常。
 FAILEDOPERATION_CALLTRADE = 'FailedOperation.CallTrade'
 
+# 第三方云服务异常，请稍后重试
+FAILEDOPERATION_CLOUDSERVICE = 'FailedOperation.CloudService'
+
 # CMQ 后台服务错误。
 FAILEDOPERATION_CMQBACKENDERROR = 'FailedOperation.CmqBackendError'
 
@@ -59,6 +62,9 @@ FAILEDOPERATION_CREATETOPIC = 'FailedOperation.CreateTopic'
 # 删除集群失败。
 FAILEDOPERATION_DELETECLUSTER = 'FailedOperation.DeleteCluster'
 
+# 群集删除保护已打开，删除群集失败。
+FAILEDOPERATION_DELETECLUSTERPROTECTION = 'FailedOperation.DeleteClusterProtection'
+
 # 删除环境角色失败。
 FAILEDOPERATION_DELETEENVIRONMENTROLES = 'FailedOperation.DeleteEnvironmentRoles'
 
@@ -80,15 +86,30 @@ FAILEDOPERATION_DELETETOPICS = 'FailedOperation.DeleteTopics'
 # 查询订阅数据失败。
 FAILEDOPERATION_DESCRIBESUBSCRIPTION = 'FailedOperation.DescribeSubscription'
 
+# 参数异常，下单失败
+FAILEDOPERATION_GENERATEDEALSANDPAYERROR = 'FailedOperation.GenerateDealsAndPayError'
+
 # 获取环境属性失败。
 FAILEDOPERATION_GETENVIRONMENTATTRIBUTESFAILED = 'FailedOperation.GetEnvironmentAttributesFailed'
 
 # 获取主题分区数失败。
 FAILEDOPERATION_GETTOPICPARTITIONSFAILED = 'FailedOperation.GetTopicPartitionsFailed'
 
+# 实例已开启删除保护功能，如需进行删除操作，请关闭删除保护。
+FAILEDOPERATION_INSTANCECANNOTDELETE = 'FailedOperation.InstanceCanNotDelete'
+
 # 实例尚未就绪，请稍后再试。
 FAILEDOPERATION_INSTANCENOTREADY = 'FailedOperation.InstanceNotReady'
 
+# 存量公网禁止修改
+FAILEDOPERATION_INVALIDEXISTPUBLICACCESSPOINTERROR = 'FailedOperation.InvalidExistPublicAccessPointError'
+
+# 参数不合法
+FAILEDOPERATION_INVALIDWHITELISTERROR = 'FailedOperation.InvalidWhiteListError'
+
+# 当前集群不支持设置该参数
+FAILEDOPERATION_ISOLATECONSUMERENABLE = 'FailedOperation.IsolateConsumerEnable'
+
 # 最大消息超过1MB。
 FAILEDOPERATION_MAXMESSAGESIZEERROR = 'FailedOperation.MaxMessageSizeError'
 
@@ -101,6 +122,12 @@ FAILEDOPERATION_MODIFYCLUSTER = 'FailedOperation.ModifyCluster'
 # 必须先清除关联命名空间才能继续操作。
 FAILEDOPERATION_NAMESPACEINUSE = 'FailedOperation.NamespaceInUse'
 
+# 删除资源不存在
+FAILEDOPERATION_ONLINEREFUNDRESOURCENOTEXIT = 'FailedOperation.OnlineRefundResourceNotExit'
+
+# 任务进行中，请稍后重试
+FAILEDOPERATION_OPERATELATER = 'FailedOperation.OperateLater'
+
 # 产品信息不存在
 FAILEDOPERATION_PRODUCTNOTEXIST = 'FailedOperation.ProductNotExist'
 
@@ -113,6 +140,12 @@ FAILEDOPERATION_RECEIVEERROR = 'FailedOperation.ReceiveError'
 # 接收消息超时，请重试。
 FAILEDOPERATION_RECEIVETIMEOUT = 'FailedOperation.ReceiveTimeout'
 
+# 跨地域复制校验不通过
+FAILEDOPERATION_REPLICATIONDESTCHECKFAILEDERROR = 'FailedOperation.ReplicationDestCheckFailedError'
+
+# 跨地域复制检验不通过
+FAILEDOPERATION_REPLICATIONSOURCECHECKFAILEDERROR = 'FailedOperation.ReplicationSourceCheckFailedError'
+
 # 消息回溯设置失败。
 FAILEDOPERATION_RESETMSGSUBOFFSETBYTIMESTAMPFAILED = 'FailedOperation.ResetMsgSubOffsetByTimestampFailed'
 
